Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Client ¶
type Client struct {
Bucket string
// contains filtered or unexported fields
}
func (*Client) Put ¶
func (c *Client) Put(filename string, perm media.Permission, reader io.ReadSeeker) (string, error)
Put saves the file on S3. If the saving process fails, it returns an empty string and an error. Else it returns the object id and no error.
Click to show internal directories.
Click to hide internal directories.